# Facilities for BriFuture

These facility scripts which will mostly be written in python is for better management of myself, but if some of them are also useful for you, you can download them (either source code or install the whole package with pip) for personal usage. It will be grateful if you make some advision or want to make some improvements over these scripts.

## License

License is GPLv3.